@@ -176,6 +176,10 @@ class AmiPipelineLib(
 
         jsii.create(AmiPipelineLib, self, [scope, id, pipeline_config, component_deps_config, slack_config])
 
+    @jsii.member(jsii_name="createCleanerTask")
+    def create_cleaner_task(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "createCleanerTask", []))
+
     @jsii.member(jsii_name="createCodepipelineProject")
     def create_codepipeline_project(self) -> None:
         return typing.cast(None, jsii.invoke(self, "createCodepipelineProject", []))
